import { createTypeSpecLibrary, paramMessage } from "@typespec/compiler";
const EmitterOptionsSchema = {
    type: "object",
    additionalProperties: true,
    properties: {
        "package-version": { type: "string", nullable: true },
        "package-name": { type: "string", nullable: true },
        "output-dir": { type: "string", nullable: true },
        "generate-packaging-files": { type: "boolean", nullable: true },
        "packaging-files-dir": { type: "string", nullable: true },
        "packaging-files-config": { type: "object", nullable: true },
        "package-pprint-name": { type: "string", nullable: true },
        "head-as-boolean": { type: "boolean", nullable: true },
        "models-mode": { type: "string", nullable: true },
        tracing: { type: "boolean", nullable: true },
        "company-name": { type: "string", nullable: true },
        "generate-test": { type: "boolean", nullable: true },
        debug: { type: "boolean", nullable: true },
        flavor: { type: "string", nullable: true },
        "examples-dir": { type: "string", nullable: true, format: "absolute-path" },
        "enable-typespec-namespace": { type: "boolean", nullable: true },
        "use-pyodide": { type: "boolean", nullable: true },
    },
    required: [],
};
const libDef = {
    name: "@typespec/http-client-python",
    diagnostics: {
        // error
        "unknown-error": {
            severity: "error",
            messages: {
                default: paramMessage `Can't generate Python client code from this TypeSpec. Please open an issue on https://github.com/microsoft/typespec'.${"stack"}`,
            },
        },
        "invalid-models-mode": {
            severity: "error",
            messages: {
                default: paramMessage `Invalid value '${"inValidValue"}' for 'models-mode' of tspconfig.yaml and expected values are 'dpg'/'none'.`,
            },
        },
        "pyodide-flag-conflict": {
            severity: "error",
            messages: {
                default: "Python is not installed. Please follow https://www.python.org/ to install Python or set 'use-pyodide' to true.",
            },
        },
        // warning
        "no-valid-client": {
            severity: "warning",
            messages: {
                default: "Can't generate Python SDK since no client defined in typespec file.",
            },
        },
        "invalid-paging-items": {
            severity: "warning",
            messages: {
                default: paramMessage `No valid paging items for operation '${"operationId"}'.`,
            },
        },
        "invalid-next-link": {
            severity: "warning",
            messages: {
                default: paramMessage `No valid next link for operation '${"operationId"}'.`,
            },
        },
        "invalid-lro-result": {
            severity: "warning",
            messages: {
                default: paramMessage `No valid LRO result for operation '${"operationId"}'.`,
            },
        },
        "invalid-continuation-token": {
            severity: "warning",
            messages: {
                default: paramMessage `No valid continuation token in '${"direction"}' for operation '${"operationId"}'.`,
            },
        },
    },
    emitter: {
        options: EmitterOptionsSchema,
    },
};
export const $lib = createTypeSpecLibrary(libDef);
export const { reportDiagnostic, createStateSymbol, getTracer } = $lib;
//# sourceMappingURL=lib.js.map